﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.ComponentModel;

/// <summary>
/// ブログ全般設定の取得・設定を行うビジネスロジッククラスです
/// </summary>
[DataObjectAttribute]
public class BlogConfigurationBL
{
    /// <summary>
    /// コンストラクタ
    /// </summary>
	public BlogConfigurationBL()
	{
	}

    /// <summary>
    /// ブログ構成情報を取得します
    /// </summary>
    /// <returns>ブログ構成テーブル</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Select)]
    public BlogConfigurationDs.BlogConfigurationDataTable GetBlogConfiguration()
    {
        BlogConfigurationDs.BlogConfigurationDataTable result = null;
        using (BlogConfigurationDsTableAdapters.BlogConfigurationTableAdapter configAdapter = new BlogConfigurationDsTableAdapters.BlogConfigurationTableAdapter())
        {
            result = configAdapter.GetData();
        }
        return result;
    }

    /// <summary>
    /// ブログ構成情報を更新します
    /// </summary>
    /// <param name="Title">ブログタイトル</param>
    /// <param name="SubTitle">ブログサブタイトル</param>
    /// <param name="ViewRecentEntryCount">最近のエントリの表示数</param>
    /// <param name="ViewRecentCommentCount">最近のコメントの表示数</param>
    /// <param name="BlogID">更新対象のブログID</param>
    /// <returns>更新したレコード数（正常であれば1）</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Update)]
    public int UpdateBlogConfiguration(string Title, string SubTitle, int ViewRecentEntryCount, int ViewRecentCommentCount, int BlogID)
    {
        int affected = 0;
        using (BlogConfigurationDsTableAdapters.BlogConfigurationTableAdapter configAdapter = new BlogConfigurationDsTableAdapters.BlogConfigurationTableAdapter())
        {
            affected = configAdapter.UpdateConfig(Title, SubTitle, ViewRecentEntryCount, ViewRecentCommentCount, DateTime.Now, BlogID);
        }
        return affected;
    }
}
