﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Transactions;
using System.ComponentModel;
using CategoryDsTableAdapters;

/// <summary>
/// エントリのカテゴリの取得・追加・削除・更新処理を行うビジネスロジッククラスです
/// </summary>
[DataObjectAttribute]
public class CategoryBL
{
    /// <summary>
    /// コンストラクタ
    /// </summary>
	public CategoryBL()
	{
	}

    /// <summary>
    /// カテゴリを追加します
    /// </summary>
    /// <param name="Text">カテゴリ名</param>
    /// <returns>追加されたレコード数（正常終了では1）</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Insert)]
    public int InsertCategory(string Text)
    {
        int affected = 0;
        using (CategoryTableAdapter categoryTA = new CategoryTableAdapter())
        {
            if (0 != categoryTA.GetCategoryCount(Text))
            {
                return -1;
            }
            affected = categoryTA.Insert(Text, DateTime.Now, DateTime.Now);
        }
        return affected;
    }

    /// <summary>
    /// カテゴリを削除します
    /// </summary>
    /// <param name="id">削除するカテゴリID</param>
    /// <returns>削除されたレコード数（正常終了では1）</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Delete)]
    public int DeleteCategory(int id)
    {
        int affected = 0;

        using (TransactionScope ts = new TransactionScope())
        {
            using (CategoryTableAdapter categoryTA = new CategoryTableAdapter())
            {
                affected = categoryTA.Delete(id);
            }
            using (EntryDsTableAdapters.EntryTableAdapter entryAdapter = new EntryDsTableAdapters.EntryTableAdapter())
            {
                entryAdapter.ResetCategory(id);
            }
            ts.Complete();
        }
        return affected;
    }

    /// <summary>
    /// カテゴリ名を更新します
    /// </summary>
    /// <param name="id">更新するカテゴリID</param>
    /// <param name="Text">新しいカテゴリ名</param>
    /// <returns>更新されたらコード数（正常終了では1）</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Update)]
    public int UpdateCategory(int id, string Text)
    {
        int affected = 0;
        using( CategoryTableAdapter categoryTA = new CategoryTableAdapter())
        {
            affected = categoryTA.Update(Text, DateTime.Now, DateTime.Now, id);
        }
        return affected;
    }

    /// <summary>
    /// すべてのカテゴリ情報を取得します
    /// </summary>
    /// <returns>カテゴリデータ</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Select)]
    public CategoryDs.CategoryDataTable GetAllCategory()
    {
        CategoryDs.CategoryDataTable result = null;
        using (CategoryTableAdapter categoryTA = new CategoryTableAdapter())
        {
            result = categoryTA.GetData();
        }
        return result;
    }

    /// <summary>
    /// 指定したIDのカテゴリ情報を取得します
    /// </summary>
    /// <param name="id">カテゴリID</param>
    /// <returns>カテゴリデータ</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Select)]
    public CategoryDs.CategoryDataTable GetCategoryByID(int id)
    {
        CategoryDs.CategoryDataTable result = null;
        using (CategoryTableAdapter categoryTA = new CategoryTableAdapter())
        {
            result = categoryTA.GetDataByID(id);
        }
        return result;
    }
}
