﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.ComponentModel;

/// <summary>
/// コメントの取得・追加・削除・更新処理を行うビジネスロジッククラスです
/// </summary>
[DataObjectAttribute]
public class CommentBL
{
    /// <summary>
    /// コンストラクタ
    /// </summary>
	public CommentBL()
	{
	}

    /// <summary>
    /// 最近追加されたコメントを取得します
    /// </summary>
    /// <returns>コメントデータ</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Select)]
    public CommentDs.CommentDataTable GetRecentComment()
    {
        BlogConfigurationDs.BlogConfigurationDataTable configTable = null;
        CommentDs.CommentDataTable commentTable = null;
        using (BlogConfigurationDsTableAdapters.BlogConfigurationTableAdapter configAdapter = new BlogConfigurationDsTableAdapters.BlogConfigurationTableAdapter())
        {
            configTable = configAdapter.GetData();
            using (CommentDsTableAdapters.CommentTableAdapter commentAdapter = new CommentDsTableAdapters.CommentTableAdapter())
            {
                commentTable = commentAdapter.GetDataRecent(configTable[0].ViewRecentCommentCount);
            }
        }
        return commentTable;
    }

    /// <summary>
    /// 指定したエントリIDに属するコメント情報を取得します
    /// </summary>
    /// <param name="parentEntryID">エントリID</param>
    /// <returns>コメントデータ</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Select)]
    public CommentDs.CommentDataTable GetCommentByEntryID(int parentEntryID)
    {
        CommentDs.CommentDataTable commentTable = null;
        using(CommentDsTableAdapters.CommentTableAdapter commentAdapter = new CommentDsTableAdapters.CommentTableAdapter())
        {
            commentTable = commentAdapter.GetDataByEntryID(parentEntryID);
        }
        return commentTable;
    }

    /// <summary>
    /// コメントを追加します
    /// </summary>
    /// <param name="parentEntryID">コメントを追加するエントリID</param>
    /// <param name="author">記述者名</param>
    /// <param name="authorsEmail">記述者 e-mail</param>
    /// <param name="authorsUrl">記述者 HPアドレス</param>
    /// <param name="contents">コメント内容</param>
    /// <returns>追加されたレコード数（正常終了では1）</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Insert)]
    public int InsertComment(int parentEntryID, string author, string authorsEmail, string authorsUrl, string contents)
    {
        int affected = 0;
        contents = contents.Replace("\r\n", "<br />");
        using (CommentDsTableAdapters.CommentTableAdapter commentAadapter = new CommentDsTableAdapters.CommentTableAdapter())
        {
            affected = commentAadapter.InsertComment(parentEntryID, contents, author, authorsEmail, authorsUrl);
        }
        return affected;
    }
}
