﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.ComponentModel;

/// <summary>
/// エントリの取得・追加・削除処理を行うビジネスロジッククラスです
/// </summary>
[DataObjectAttribute]
public class LinkBL
{
    /// <summary>
    /// コンストラクタ
    /// </summary>
	public LinkBL()
	{
	}

    /// <summary>
    /// 指定したIDのリンク情報を取得します
    /// </summary>
    /// <param name="ID">リンクID</param>
    /// <returns>リンクデータ</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Select)]
    public LinkDs.LinkDataTable GetLink(int ID)
    {
        LinkDs.LinkDataTable result = null;
        using (LinkDsTableAdapters.LinkTableAdapter adapter = new LinkDsTableAdapters.LinkTableAdapter())
        {
            result = adapter.GetDataByID(ID);
        }
        return result;
    }

    /// <summary>
    /// すべてのリンク情報を取得します
    /// </summary>
    /// <returns>リンクデータ</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Select)]
    public LinkDs.LinkDataTable GetAllLink()
    {
        LinkDs.LinkDataTable result = null;
        using (LinkDsTableAdapters.LinkTableAdapter adapter = new LinkDsTableAdapters.LinkTableAdapter())
        {
            result = adapter.GetData();
        }
        return result;
    }

    /// <summary>
    /// リンク情報を追加します
    /// </summary>
    /// <param name="Title">タイトル</param>
    /// <param name="Image">画像</param>
    /// <param name="Comment">コメント</param>
    /// <param name="Url">リンク先URL</param>
    /// <returns>追加されたレコード数（正常終了は1）</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Insert)]
    public int InsertLink(string Title, string Image, string Comment, string Url)
    {
        int affected = 0;
        using (LinkDsTableAdapters.LinkTableAdapter linkAtapter = new LinkDsTableAdapters.LinkTableAdapter())
        {
            affected =linkAtapter.Insert(Title, Image, Comment, Url, DateTime.Now, DateTime.Now);
        }
        return affected;
    }

    /// <summary>
    /// 指定したIDのリンク情報を削除します
    /// </summary>
    /// <param name="ID">リンクID</param>
    /// <returns>削除したレコード数（正常終了は1）</returns>
    [DataObjectMethodAttribute(DataObjectMethodType.Delete)]
    public int DeleteLink(int ID)
    {
        int affected = 0;
        using (LinkDsTableAdapters.LinkTableAdapter linkAtapter = new LinkDsTableAdapters.LinkTableAdapter())
        {
            LinkDs.LinkDataTable linkTable = linkAtapter.GetDataByID(ID);
            affected = linkAtapter.Delete(ID);
            DeleteLinkImageFile(linkTable[0].Image);
        }
        return affected;
    }

    /// <summary>
    /// リンク情報に付加された画像ファイルをファイルシステムから削除します
    /// </summary>
    /// <param name="imageUrl">画像URL</param>
    public void DeleteLinkImageFile(string imageUrl)
    {
        string mapPath = HttpContext.Current.Server.MapPath(imageUrl);
        File.Delete(mapPath);
    }

    /// <summary>
    /// リンク情報に付加された画像ファイルをファイルシステムに保存します
    /// </summary>
    /// <param name="fileUpload">画像情報を所有したFileUploadサーバーコントロール</param>
    /// <returns></returns>
    public string SaveLinkImageFile(FileUpload fileUpload)
    {
        string result = "";
        if (fileUpload.HasFile)
        {
            result = "~/Image/Link/" + fileUpload.FileName;
            string mapPath = HttpContext.Current.Server.MapPath("~/Image/Link/");
            string fullPath = Path.Combine(mapPath, fileUpload.FileName);
            if (!Directory.Exists( mapPath ))
            {
                Directory.CreateDirectory(mapPath);
            }
            fileUpload.SaveAs(fullPath);
        }
        return result;
    }
}
