﻿using System;
using System.Data;
using System.Data.SqlClient;
using System.Web;
using System.Collections.Specialized;

/// <summary>
/// SqlSiteMapProvider の概要の説明です
/// </summary>
public class SqlSiteMapProvider : StaticSiteMapProvider
{
    // ルートノードオブジェクト
    private SiteMapNode rootNode = null;

    // SQL Serverコネクションオブジェクト
    private SqlConnection sqlConnection = null;

    // 構成の接続文字列キー名
    private string SqlConnectionStringName = "SqlConnectionString";

    // ルートノードを取得します．
    public override SiteMapNode RootNode
    {
        get { return BuildSiteMap(); }
    }

    // コンストラクタ
    public SqlSiteMapProvider() { }

    /// <summary>
    /// プロバイダの初期処理をします
    /// </summary>
    /// <param name="name"></param>
    /// <param name="attributes"></param>
    public override void Initialize(
        string name,
        NameValueCollection attributes)
    {
        base.Initialize(name, attributes);

        // 構成からＤＢ接続文字列を取得
        string connectionString = attributes[SqlConnectionStringName];

        sqlConnection = new SqlConnection(connectionString);
    }

    /// <summary>
    /// サイトマップ情報をメモリに読み込みます．
    /// </summary>
    /// <returns></returns>
    public override SiteMapNode BuildSiteMap()
    {
        lock (this)
        {
            if (null == rootNode)
            { // ２度目以降は再読み込みしない
                // ノード情報をクリア
                Clear();

                // ＤＢからすべてのノード情報をDataSetに取得
                DataSet ds = new DataSet();
                SqlDataAdapter adapter =
                  new SqlDataAdapter(
                    "SELECT * FROM SiteMapTable ORDER BY ParentID",
                    this.sqlConnection);
                adapter.Fill(ds);

                // ルートノードオブジェクトを作成
                rootNode = new SiteMapNode(
                  this,
                  ds.Tables[0].Rows[0]["ID"].ToString(),
                  (string)(ds.Tables[0].Rows[0]["Url"]),
                  (string)(ds.Tables[0].Rows[0]["Title"]),
                  (string)(ds.Tables[0].Rows[0]["Description"]));
                AddNode(rootNode);

                // ルートノードの子ノードを構築
                BuildChildNode(ds, rootNode);
            }
        }

        return rootNode;
    }

    /// <summary>
    /// 引数parentNodeの子ノードを構築します
    /// </summary>
    /// <param name="ds">全サイトマップ情報の格納されたDataSet</param>
    /// <param name="parentNode">このノードの子を構築します</param>
    private void BuildChildNode(DataSet ds, SiteMapNode parentNode)
    {
        // 子ノードを一覧するためのビューを作成
        DataView view = new DataView(
          ds.Tables[0],
          "ParentID = " + parentNode.Key,
          "",
          DataViewRowState.CurrentRows);

        // 子ノード構築
        foreach (DataRowView row in view)
        {
            int id = (int)row["ID"];
            SiteMapNode node = new SiteMapNode(
              this,
              id.ToString(),
              (string)row["Url"],
              (string)row["Title"],
              (string)row["Description"]);
            AddNode(node, parentNode);

            // 子の子を再帰的に構築
            BuildChildNode(ds, node);
        }
    }

    /// <summary>
    /// 全ノードを取得します
    /// </summary>
    /// <returns></returns>
    protected override SiteMapNode GetRootNodeCore()
    {
        return this.BuildSiteMap();
    }

    /// <summary>
    /// ノード情報をクリアします
    /// </summary>
    protected override void Clear()
    {
        lock (this)
        {
            rootNode = null;
            base.Clear();
        }
    }
}
